Index: trunk/psModules/test/camera/tap_pmFPAMaskW.c
===================================================================
--- trunk/psModules/test/camera/tap_pmFPAMaskW.c	(revision 21220)
+++ trunk/psModules/test/camera/tap_pmFPAMaskW.c	(revision 21474)
@@ -62,10 +62,10 @@
     readout->image = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
     readout->mask = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_U8);
-    readout->weight = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
+    readout->variance = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
     for (int i = 0 ; i < TEST_NUM_ROWS ; i++) {
         for (int j = 0 ; j < TEST_NUM_COLS ; j++) {
             readout->image->data.F32[i][j] = 32.0;
             readout->mask->data.U8[i][j] = 0;
-            readout->weight->data.F32[i][j] = 1.0;
+            readout->variance->data.F32[i][j] = 1.0;
 	}
     }
@@ -108,12 +108,12 @@
     cell->hdu->images = psArrayAlloc(NUM_HDUS);
     cell->hdu->masks = psArrayAlloc(NUM_HDUS);
-    cell->hdu->weights = psArrayAlloc(NUM_HDUS);
+    cell->hdu->variances = psArrayAlloc(NUM_HDUS);
     for (int k = 0 ; k < NUM_HDUS ; k++) {
         cell->hdu->images->data[k]  = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
         cell->hdu->masks->data[k]   = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_MASK);
-        cell->hdu->weights->data[k] = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
+        cell->hdu->variances->data[k] = psImageAlloc(TEST_NUM_COLS, TEST_NUM_ROWS, PS_TYPE_F32);
         psImageInit(cell->hdu->images->data[k], (float) (BASE_IMAGE+k));
         psImageInit(cell->hdu->masks->data[k], (psU8) (BASE_MASK+k));
-        psImageInit(cell->hdu->weights->data[k], (float) (BASE_WEIGHT+k));
+        psImageInit(cell->hdu->variances->data[k], (float) (BASE_WEIGHT+k));
     }
 
@@ -355,6 +355,6 @@
 
     // ----------------------------------------------------------------------
     // pmReadoutSetWeight() tests: NULL inputs
     // bool pmReadoutSetWeight(pmReadout *readout, bool poisson)
     if (1) {
         psMemId id = psMemGetId();
@@ -366,7 +366,7 @@
         bool rc;
 
-        // Set readout == NULL, ensure pmReadoutSetWeight() returnes FALSE, with no seg faults, memory leaks
-        rc = pmReadoutSetWeight(NULL, false);
-        ok(!rc, "pmReadoutSetWeight(NULL, false) returned FALSE with null pmReadout input");
+        // Set readout == NULL, ensure pmReadoutSetVariance() returnes FALSE, with no seg faults, memory leaks
+        rc = pmReadoutSetVariance(NULL, false);
+        ok(!rc, "pmReadoutSetVariance(NULL, false) returned FALSE with null pmReadout input");
 
 
@@ -376,15 +376,15 @@
         ok(rc, "Set GAIN and READNOISE in cell->concepts successfully");
 
-        // Call pmReadoutSetWeight() and then verify that the mask data was set correctly
-        rc = pmReadoutSetWeight(readout, false);
-        ok(rc, "pmReadoutSetWeight(readout, false) returned TRUE with acceptable input data");
+        // Call pmReadoutSetVariance() and then verify that the mask data was set correctly
+        rc = pmReadoutSetVariance(readout, false);
+        ok(rc, "pmReadoutSetVariance(readout, false) returned TRUE with acceptable input data");
         bool errorFlag = false;
-        for (int i = 0 ; i < readout->weight->numRows ; i++) {
-            for (int j = 0 ; j < readout->weight->numCols ; j++) {
+        for (int i = 0 ; i < readout->variance->numRows ; i++) {
+            for (int j = 0 ; j < readout->variance->numCols ; j++) {
                 psF32 exp = CELL_READNOISE * CELL_READNOISE / CELL_GAIN / CELL_GAIN;
-                if(abs(readout->weight->data.F32[i][j] - exp) > 1e-4) {
+                if(abs(readout->variance->data.F32[i][j] - exp) > 1e-4) {
                     if (VERBOSE) {
                         diag("TEST ERROR: weight[%d][%d] is %.2f, should be %.2f\n",
-                              i, j, readout->weight->data.F32[i][j], exp);
+                              i, j, readout->variance->data.F32[i][j], exp);
 		    }
                     errorFlag = true;
@@ -392,5 +392,5 @@
 	    }
 	}
-        ok(!errorFlag, "pmReadoutSetWeight() set the weight values correctly (non-Poisson)");
+        ok(!errorFlag, "pmReadoutSetVariance() set the weight values correctly (non-Poisson)");
 
         for (int i = 0 ; i < readout->image->numRows ; i++) {
@@ -399,17 +399,17 @@
 	    }
 	}
-        // Call pmReadoutSetWeight() and then verify that the mask data was set correctly
-        rc = pmReadoutSetWeight(readout, true);
-        ok(rc, "pmReadoutSetWeight(readout, true) returned TRUE with acceptable input data");
+        // Call pmReadoutSetVariance() and then verify that the mask data was set correctly
+        rc = pmReadoutSetVariance(readout, true);
+        ok(rc, "pmReadoutSetVariance(readout, true) returned TRUE with acceptable input data");
         errorFlag = false;
-        for (int i = 0 ; i < readout->weight->numRows ; i++) {
-            for (int j = 0 ; j < readout->weight->numCols ; j++) {
+        for (int i = 0 ; i < readout->variance->numRows ; i++) {
+            for (int j = 0 ; j < readout->variance->numCols ; j++) {
                 psF32 exp = abs(readout->image->data.F32[i][j] / CELL_GAIN); 
                 if (exp < 1.0) exp = 1.0;
                 exp+= CELL_READNOISE * CELL_READNOISE / CELL_GAIN / CELL_GAIN;
-                if(abs(readout->weight->data.F32[i][j] - exp) > 1e-4) {
+                if(abs(readout->variance->data.F32[i][j] - exp) > 1e-4) {
                     if (VERBOSE) {
                         diag("TEST ERROR: weight[%d][%d] is %.2f, should be %.2f\n",
-                              i, j, readout->weight->data.F32[i][j], exp);
+                              i, j, readout->variance->data.F32[i][j], exp);
 		    }
                     errorFlag = true;
@@ -355,6 +355,6 @@
 
     // ----------------------------------------------------------------------
-    // pmReadoutSetWeight() tests: NULL inputs
-    // bool pmReadoutSetWeight(pmReadout *readout, bool poisson)
+    // pmReadoutSetVariance() tests: NULL inputs
+    // bool pmReadoutSetVariance(pmReadout *readout, bool poisson)
     if (1) {
         psMemId id = psMemGetId();
